@@ -17,8 +17,11 @@ import errno
 import functools
 import json
 import os
+try:
+    from unittest import mock
+except ImportError:
+    import mock
 
-import mock
 from oslotest import base
 from testscenarios import load_tests_apply_scenarios as load_tests  # noqa
 
@@ -29,7 +32,7 @@ sample_data_path = os.path.join(
     os.path.dirname(os.path.realpath(__file__)), 'fixtures')
 
 distros = ['Ubuntu', 'Debian', 'Fedora', 'RedHat', 'CentOS', 'Gentoo',
-           'openSUSE', 'networkd']
+           'openSUSE', 'networkd', 'Rocky']
 styles = ['hp', 'rax', 'rax-iad', 'liberty', 'nokey', 'ovh']
 ips = {'hp': '127.0.1.1',
        'rax': '23.253.229.154',
@@ -221,8 +224,7 @@ class TestGlean(base.BaseTestCase):
         with open(output_path) as f:
             for line in f:
                 if line == '%NM_CONTROLLED%\n':
-                        line = 'NM_CONTROLLED=%s\n' % \
-                            ("yes" if use_nm else "no")
+                    line = 'NM_CONTROLLED=%s\n' % ("yes" if use_nm else "no")
                 lines.append(line)
         write_dest = None
         write_content = None
@@ -264,9 +266,9 @@ class TestGlean(base.BaseTestCase):
             hostname = meta_data['name']
 
         mock_call.assert_has_calls([mock.call(['hostname', hostname])])
-        if distro.lower() is 'gentoo':
+        if distro.lower() == 'gentoo':
             (self.file_handle_mocks['/etc/conf.d/hostname'].write.
-                assert_has_calls([mock.call(hostname)]))
+                assert_has_calls([mock.call('hostname="%s"\n' % hostname)]))
         else:
             self.file_handle_mocks['/etc/hostname'].write.assert_has_calls(
                 [mock.call(hostname), mock.call('\n')])
